==> cf-component-modal-7.0.15.tgz: package/es/Modal.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { default as ReactModal2 } from 'react-modal2';
import { Gateway } from 'react-gateway';
import { createComponent, createComponentStyles } from 'cf-style-container';

var BackdropScroller = createComponent(function (_ref) {
  var theme = _ref.theme;
  return {
    position: 'fixed',
    top: 0,
    bottom: 0,
    left: 0,
    right: 0,
    zIndex: theme.zIndexModal,
    overflow: 'auto',
    overflowX: 'hidden',
    overflowY: 'auto',
    '-webkit-overflow-scrolling': 'touch'
  };
});

var BackdropOuter = createComponent(function () {
  return {
    position: 'relative',
    width: '100%',
    height: '100%',
    display: 'table'
  };
});

var modalStyles = function modalStyles(_ref2) {
  var theme = _ref2.theme,
      width = _ref2.width;
  return {
    position: 'relative',
    width: '100%',
    maxWidth: width ? getWidth(width) : '30rem',
    margin: '0 auto',
    background: theme.colors.white,
    transformOrigin: 'center',
    backfaceVisibility: 'hidden',
    borderRadius: '2px',
    boxShadow: '0 1px 15px rgba(0,0,0,.75)',
    '&:focus': {
      outline: 'none'
    }
  };
};

var backdropStyles = function backdropStyles() {
  return {
    display: 'table-cell',
    verticalAlign: 'middle',
    padding: '1.5rem',
    '-webkit-transform-origin': 'center',
    transformOrigin: 'center',
    background: 'rgba(0,0,0,.7)'
  };
};

var getWidth = function getWidth(width) {
  switch (width) {
    case 'wide':
      return '40rem';
    case 'extra-wide':
      return '53.33rem';
    case 'super-extra-wide':
      return '80rem';
    default:
      return '30rem';
  }
};

var Modal = function (_React$Component) {
  _inherits(Modal, _React$Component);

  function Modal() {
    _classCallCheck(this, Modal);

    return _possibleConstructorReturn(this, (Modal.__proto__ || Object.getPrototypeOf(Modal)).apply(this, arguments));
  }

  _createClass(Modal, [{
    key: 'render',
    value: function render() {
      var _props = this.props,
          styles = _props.styles,
          isOpen = _props.isOpen,
          closeOnEsc = _props.closeOnEsc,
          closeOnBackdropClick = _props.closeOnBackdropClick,
          onRequestClose = _props.onRequestClose,
          children = _props.children;


      return React.createElement(
        Gateway,
        { into: 'modal' },
        isOpen && React.createElement(
          BackdropScroller,
          null,
          React.createElement(
            BackdropOuter,
            null,
            React.createElement(
              ReactModal2,
              {
                key: 'modal',
                backdropClassName: styles.backdropStyles,
                modalClassName: styles.modalStyles,
                closeOnEsc: closeOnEsc,
                closeOnBackdropClick: closeOnBackdropClick,
                onClose: onRequestClose
              },
              children
            )
          )
        )
      );
    }
  }]);

  return Modal;
}(React.Component);

Modal.propTypes = {
  styles: PropTypes.object,
  isOpen: PropTypes.bool.isRequired,
  onRequestClose: PropTypes.func.isRequired,
  closeOnEsc: PropTypes.bool,
  closeOnBackdropClick: PropTypes.bool,
  children: PropTypes.node,
  width: PropTypes.string
};

Modal.defaultProps = {
  closeOnEsc: true,
  closeOnBackdropClick: true
};

export default createComponentStyles({ modalStyles: modalStyles, backdropStyles: backdropStyles }, Modal);

==> cf-component-modal-7.1.6.tgz: package/es/Modal.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { Portal } from 'react-portal';
import { default as ReactModal2 } from 'react-modal2';
import { createComponent, createComponentStyles } from 'cf-style-container';

// document.body.lastElementChild polyfill
if (window) {
  (function (constructor) {
    if (constructor && constructor.prototype && constructor.prototype.lastElementChild === null) {
      Object.defineProperty(constructor.prototype, 'lastElementChild', {
        get: function get() {
          var node,
              nodes = this.childNodes,
              i = nodes.length - 1;
          while (node = nodes[i--]) {
            if (node.nodeType === 1) {
              return node;
            }
          }
          return null;
        }
      });
    }
  })(window.Node || window.Element);
}

var BackdropScroller = createComponent(function (_ref) {
  var theme = _ref.theme;
  return {
    position: 'fixed',
    top: 0,
    bottom: 0,
    left: 0,
    right: 0,
    zIndex: theme.zIndexModal,
    overflow: 'auto',
    overflowX: 'hidden',
    overflowY: 'auto',
    '-webkit-overflow-scrolling': 'touch'
  };
});
BackdropScroller.setDisplayName('BackdropScroller');

var BackdropOuter = createComponent(function () {
  return {
    position: 'relative',
    width: '100%',
    height: '100%',
    display: 'table'
  };
});
BackdropOuter.setDisplayName('BackdropOuter');

var modalStyles = function modalStyles(_ref2) {
  var theme = _ref2.theme,
      width = _ref2.width;
  return {
    position: 'relative',
    width: '100%',
    maxWidth: width ? getWidth(width) : '30rem',
    margin: '0 auto',
    background: theme.colors.white,
    transformOrigin: 'center',
    backfaceVisibility: 'hidden',
    borderRadius: '2px',
    boxShadow: '0 1px 15px rgba(0,0,0,.75)',
    '&:focus': {
      outline: 'none'
    }
  };
};

var backdropStyles = function backdropStyles() {
  return {
    display: 'table-cell',
    verticalAlign: 'middle',
    padding: '1.5rem',
    '-webkit-transform-origin': 'center',
    transformOrigin: 'center',
    background: 'rgba(0,0,0,.7)'
  };
};

var getWidth = function getWidth(width) {
  switch (width) {
    case 'wide':
      return '40rem';
    case 'extra-wide':
      return '53.33rem';
    case 'super-extra-wide':
      return '80rem';
    default:
      return '30rem';
  }
};

var Modal = function (_React$Component) {
  _inherits(Modal, _React$Component);

  function Modal() {
    _classCallCheck(this, Modal);

    return _possibleConstructorReturn(this, (Modal.__proto__ || Object.getPrototypeOf(Modal)).apply(this, arguments));
  }

  _createClass(Modal, [{
    key: 'render',
    value: function render() {
      var _props = this.props,
          styles = _props.styles,
          isOpen = _props.isOpen,
          closeOnEsc = _props.closeOnEsc,
          closeOnBackdropClick = _props.closeOnBackdropClick,
          onRequestClose = _props.onRequestClose,
          children = _props.children;


      return isOpen ? React.createElement(
        Portal,
        null,
        React.createElement(
          BackdropScroller,
          null,
          React.createElement(
            BackdropOuter,
            null,
            React.createElement(
              ReactModal2,
              {
                key: 'modal',
                backdropClassName: styles.backdropStyles,
                modalClassName: styles.modalStyles,
                closeOnEsc: closeOnEsc,
                closeOnBackdropClick: closeOnBackdropClick,
                onClose: onRequestClose
              },
              children
            )
          )
        )
      ) : null;
    }
  }]);

  return Modal;
}(React.Component);

Modal.propTypes = {
  styles: PropTypes.object,
  isOpen: PropTypes.bool.isRequired,
  onRequestClose: PropTypes.func.isRequired,
  closeOnEsc: PropTypes.bool,
  closeOnBackdropClick: PropTypes.bool,
  children: PropTypes.node,
  width: PropTypes.string
};

Modal.defaultProps = {
  closeOnEsc: true,
  closeOnBackdropClick: true
};
Modal.displayName = 'Modal';

ReactModal2.getApplicationElement = function () {
  return document.body.lastElementChild;
};

export default createComponentStyles({ modalStyles: modalStyles, backdropStyles: backdropStyles }, Modal);
